@@ -7,16 +7,16 @@ from contextlib import suppress
 
 from funcy import cached_property
 
+from dvc.exceptions import DvcException
+from dvc.progress import Tqdm
+from dvc.remote.base import RemoteCmdError
+from dvc.utils import tmp_fname
+
 try:
     import paramiko
 except ImportError:
     paramiko = None
 
-from dvc.utils import tmp_fname
-from dvc.progress import Tqdm
-from dvc.exceptions import DvcException
-from dvc.remote.base import RemoteCmdError
-
 
 logger = logging.getLogger(__name__)
 
@@ -25,9 +25,9 @@ def sizeof_fmt(num, suffix="B"):
     """ Convert number of bytes to human-readable string """
     for unit in ["", "K", "M", "G", "T", "P", "E", "Z"]:
         if abs(num) < 1024.0:
-            return "%3.1f%s%s" % (num, unit, suffix)
+            return f"{num:3.1f}{unit}{suffix}"
         num /= 1024.0
-    return "%.1f%s%s" % (num, "Y", suffix)
+    return "{:.1f}{}{}".format(num, "Y", suffix)
 
 
 class SSHConnection:
@@ -100,7 +100,7 @@ class SSHConnection:
 
         if stat.S_ISREG(st_mode) or stat.S_ISLNK(st_mode):
             raise DvcException(
-                "a file with the same name '{}' already exists".format(path)
+                f"a file with the same name '{path}' already exists"
             )
 
         head, tail = posixpath.split(path)
@@ -111,12 +111,12 @@ class SSHConnection:
         if tail:
             try:
                 self.sftp.mkdir(path)
-            except IOError as exc:
+            except OSError as exc:
                 # Since paramiko errors are very vague we need to recheck
                 # whether it's because path already exists or something else
                 if exc.errno == errno.EACCES or not self.exists(path):
                     raise DvcException(
-                        "unable to create remote directory '{}'".format(path)
+                        f"unable to create remote directory '{path}'"
                     ) from exc
 
     def walk(self, directory, topdown=True):
@@ -126,7 +126,7 @@ class SSHConnection:
         # [1] https://github.com/python/cpython/blob/master/Lib/os.py
         try:
             dir_entries = self.sftp.listdir_attr(directory)
-        except IOError as exc:
+        except OSError as exc:
             raise DvcException(
                 "couldn't get the '{}' remote directory files list".format(
                     directory
@@ -153,7 +153,7 @@ class SSHConnection:
             yield directory, dirs, nondirs
 
     def walk_files(self, directory):
-        for root, dirs, files in self.walk(directory):
+        for root, _, files in self.walk(directory):
             for fname in files:
                 yield posixpath.join(root, fname)
 
@@ -237,11 +237,15 @@ class SSHConnection:
             or channel.recv_ready()
             or channel.recv_stderr_ready()
         ):
-            import select
+            import selectors
+
+            selector = selectors.DefaultSelector()
+            selector.register(stdout.channel, selectors.EVENT_READ)
 
             got_chunk = False
-            readq, _, _ = select.select([stdout.channel], [], [], self.timeout)
-            for c in readq:
+            events = selector.select(self.timeout)
+            for key, _ in events:
+                c = key.fileobj
                 if c.recv_ready():
                     stdout_chunks.append(stdout.channel.recv(len(c.in_buffer)))
                     got_chunk = True
@@ -292,14 +296,14 @@ class SSHConnection:
             md5 = self.execute("md5 " + path).split()[-1]
         else:
             raise DvcException(
-                "'{}' is not supported as a SSH remote".format(self.uname)
+                f"'{self.uname}' is not supported as a SSH remote"
             )
 
         assert len(md5) == 32
         return md5
 
     def copy(self, src, dest):
-        self.execute("cp {} {}".format(src, dest))
+        self.execute(f"cp {src} {dest}")
 
     def open_max_sftp_channels(self):
         # If there are more than 1 it means we've already opened max amount
@@ -321,14 +325,12 @@ class SSHConnection:
 
     def reflink(self, src, dest):
         if self.uname == "Linux":
-            return self.execute("cp --reflink {} {}".format(src, dest))
+            return self.execute(f"cp --reflink {src} {dest}")
 
         if self.uname == "Darwin":
-            return self.execute("cp -c {} {}".format(src, dest))
+            return self.execute(f"cp -c {src} {dest}")
 
-        raise DvcException(
-            "'{}' is not supported as a SSH remote".format(self.uname)
-        )
+        raise DvcException(f"'{self.uname}' is not supported as a SSH remote")
 
     def hardlink(self, src, dest):
-        self.execute("ln {} {}".format(src, dest))
+        self.execute(f"ln {src} {dest}")
